@@ -29,7 +29,7 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Resources::Customer;
+use Google::Ads::GoogleAds::V4::Resources::Customer;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -50,7 +50,7 @@ sub create_customer {
   my ($api_client, $manager_customer_id) = @_;
 
   # Initialize a customer to be created.
-  my $customer = Google::Ads::GoogleAds::V3::Resources::Customer->new({
+  my $customer = Google::Ads::GoogleAds::V4::Resources::Customer->new({
       descriptiveName => "Account created with CustomerService on #" . uniqid(),
 
       # For a list of valid currency codes and time zones, see this documentation:
@@ -86,7 +86,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
