@@ -25,7 +25,7 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Utils::ResourceNames;
+use Google::Ads::GoogleAds::V4::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -45,7 +45,7 @@ sub get_account_information {
   my ($api_client, $customer_id) = @_;
 
   my $resource_name =
-    Google::Ads::GoogleAds::V3::Utils::ResourceNames::customer($customer_id);
+    Google::Ads::GoogleAds::V4::Utils::ResourceNames::customer($customer_id);
 
   my $customer =
     $api_client->CustomerService()->get({resourceName => $resource_name});
@@ -68,7 +68,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
