@@ -25,29 +25,29 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Resources::FeedAttribute;
-use Google::Ads::GoogleAds::V3::Resources::Feed;
-use Google::Ads::GoogleAds::V3::Resources::AttributeFieldMapping;
-use Google::Ads::GoogleAds::V3::Resources::FeedMapping;
-use Google::Ads::GoogleAds::V3::Resources::FeedItemAttributeValue;
-use Google::Ads::GoogleAds::V3::Resources::FeedItem;
-use Google::Ads::GoogleAds::V3::Resources::FeedItemTarget;
-use Google::Ads::GoogleAds::V3::Resources::Ad;
-use Google::Ads::GoogleAds::V3::Resources::AdGroupAd;
-use Google::Ads::GoogleAds::V3::Common::ExpandedTextAdInfo;
-use Google::Ads::GoogleAds::V3::Enums::FeedAttributeTypeEnum
+use Google::Ads::GoogleAds::V4::Resources::FeedAttribute;
+use Google::Ads::GoogleAds::V4::Resources::Feed;
+use Google::Ads::GoogleAds::V4::Resources::AttributeFieldMapping;
+use Google::Ads::GoogleAds::V4::Resources::FeedMapping;
+use Google::Ads::GoogleAds::V4::Resources::FeedItemAttributeValue;
+use Google::Ads::GoogleAds::V4::Resources::FeedItem;
+use Google::Ads::GoogleAds::V4::Resources::FeedItemTarget;
+use Google::Ads::GoogleAds::V4::Resources::Ad;
+use Google::Ads::GoogleAds::V4::Resources::AdGroupAd;
+use Google::Ads::GoogleAds::V4::Common::ExpandedTextAdInfo;
+use Google::Ads::GoogleAds::V4::Enums::FeedAttributeTypeEnum
   qw(STRING DATE_TIME);
-use Google::Ads::GoogleAds::V3::Enums::FeedOriginEnum qw(USER);
-use Google::Ads::GoogleAds::V3::Enums::AdCustomizerPlaceholderFieldEnum;
-use Google::Ads::GoogleAds::V3::Enums::PlaceholderTypeEnum qw(AD_CUSTOMIZER);
-use Google::Ads::GoogleAds::V3::Services::FeedService::FeedOperation;
+use Google::Ads::GoogleAds::V4::Enums::FeedOriginEnum qw(USER);
+use Google::Ads::GoogleAds::V4::Enums::AdCustomizerPlaceholderFieldEnum;
+use Google::Ads::GoogleAds::V4::Enums::PlaceholderTypeEnum qw(AD_CUSTOMIZER);
+use Google::Ads::GoogleAds::V4::Services::FeedService::FeedOperation;
 use
-  Google::Ads::GoogleAds::V3::Services::FeedMappingService::FeedMappingOperation;
-use Google::Ads::GoogleAds::V3::Services::FeedItemService::FeedItemOperation;
+  Google::Ads::GoogleAds::V4::Services::FeedMappingService::FeedMappingOperation;
+use Google::Ads::GoogleAds::V4::Services::FeedItemService::FeedItemOperation;
 use
-  Google::Ads::GoogleAds::V3::Services::FeedItemTargetService::FeedItemTargetOperation;
-use Google::Ads::GoogleAds::V3::Services::AdGroupAdService::AdGroupAdOperation;
-use Google::Ads::GoogleAds::V3::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V4::Services::FeedItemTargetService::FeedItemTargetOperation;
+use Google::Ads::GoogleAds::V4::Services::AdGroupAdService::AdGroupAdOperation;
+use Google::Ads::GoogleAds::V4::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -57,6 +57,8 @@ use POSIX qw(strftime mktime);
 
 # We're doing only searches by resource_name in this example, we can set page size = 1.
 use constant PAGE_SIZE => 1;
+# We're creating two different ad groups to be dynamically populated by the same feed.
+use constant NUMBER_OF_AD_GROUPS => 2;
 
 # The following parameter(s) should be provided to run the example. You can
 # either specify these by changing the INSERT_XXX_ID_HERE values below, or on
@@ -69,9 +71,15 @@ use constant PAGE_SIZE => 1;
 my $customer_id   = "INSERT_CUSTOMER_ID_HERE";
 my $ad_group_id_1 = "INSERT_AD_GROUP_ID_1_HERE";
 my $ad_group_id_2 = "INSERT_AD_GROUP_ID_2_HERE";
+my $ad_group_ids  = [];
 
 sub add_ad_customizer {
-  my ($api_client, $customer_id, $ad_group_id_1, $ad_group_id_2) = @_;
+  my ($api_client, $customer_id, $ad_group_ids) = @_;
+
+  die sprintf
+    "Please pass exactly %d ad group IDs in the ad_group_ids parameter.\n",
+    NUMBER_OF_AD_GROUPS
+    if scalar @$ad_group_ids != NUMBER_OF_AD_GROUPS;
 
   my $feed_name = "Ad Customizer example feed " . uniqid();
 
@@ -99,13 +107,12 @@ sub add_ad_customizer {
   );
 
   # Set the feed to be used only with the specified ad groups.
-  create_feed_item_targets($api_client, $customer_id,
-    [$ad_group_id_1, $ad_group_id_2],
+  create_feed_item_targets($api_client, $customer_id, $ad_group_ids,
     $feed_item_resource_names);
 
   # Create ads that use the feed for customization.
-  create_ads_with_customizations($api_client, $customer_id,
-    [$ad_group_id_1, $ad_group_id_2], $feed_name);
+  create_ads_with_customizations($api_client, $customer_id, $ad_group_ids,
+    $feed_name);
 
   return 1;
 }
@@ -117,25 +124,25 @@ sub create_ad_customizer_feed {
   # Create three feed attributes: a name, a price and a date. The attribute names
   # are arbitrary choices and will be used as placeholders in the ad text fields.
   my $name_attribute =
-    Google::Ads::GoogleAds::V3::Resources::FeedAttribute->new({
+    Google::Ads::GoogleAds::V4::Resources::FeedAttribute->new({
       type => STRING,
       name => "Name"
     });
 
   my $price_attribute =
-    Google::Ads::GoogleAds::V3::Resources::FeedAttribute->new({
+    Google::Ads::GoogleAds::V4::Resources::FeedAttribute->new({
       type => STRING,
       name => "Price"
     });
 
   my $date_attribute =
-    Google::Ads::GoogleAds::V3::Resources::FeedAttribute->new({
+    Google::Ads::GoogleAds::V4::Resources::FeedAttribute->new({
       type => DATE_TIME,
       name => "Date"
     });
 
   # Create the feed.
-  my $feed = Google::Ads::GoogleAds::V3::Resources::Feed->new({
+  my $feed = Google::Ads::GoogleAds::V4::Resources::Feed->new({
     name       => $feed_name,
     attributes => [$name_attribute, $price_attribute, $date_attribute],
     origin     => USER
@@ -143,7 +150,7 @@ sub create_ad_customizer_feed {
 
   # Create a feed operation for creating a feed.
   my $feed_operation =
-    Google::Ads::GoogleAds::V3::Services::FeedService::FeedOperation->new({
+    Google::Ads::GoogleAds::V4::Services::FeedService::FeedOperation->new({
       create => $feed
     });
 
@@ -194,28 +201,28 @@ sub create_ad_customizer_mapping {
 
   # Map the feed attribute IDs to the field ID constants.
   my $name_field_mapping =
-    Google::Ads::GoogleAds::V3::Resources::AttributeFieldMapping->new({
+    Google::Ads::GoogleAds::V4::Resources::AttributeFieldMapping->new({
       feedAttributeId => $ad_customizer_feed_attributes->{Name},
       adCustomizerField =>
-        Google::Ads::GoogleAds::V3::Enums::AdCustomizerPlaceholderFieldEnum::STRING,
+        Google::Ads::GoogleAds::V4::Enums::AdCustomizerPlaceholderFieldEnum::STRING,
     });
 
   my $price_field_mapping =
-    Google::Ads::GoogleAds::V3::Resources::AttributeFieldMapping->new({
+    Google::Ads::GoogleAds::V4::Resources::AttributeFieldMapping->new({
       feedAttributeId => $ad_customizer_feed_attributes->{Price},
       adCustomizerField =>
-        Google::Ads::GoogleAds::V3::Enums::AdCustomizerPlaceholderFieldEnum::PRICE,
+        Google::Ads::GoogleAds::V4::Enums::AdCustomizerPlaceholderFieldEnum::PRICE,
     });
 
   my $date_field_mapping =
-    Google::Ads::GoogleAds::V3::Resources::AttributeFieldMapping->new({
+    Google::Ads::GoogleAds::V4::Resources::AttributeFieldMapping->new({
       feedAttributeId => $ad_customizer_feed_attributes->{Date},
       adCustomizerField =>
-        Google::Ads::GoogleAds::V3::Enums::AdCustomizerPlaceholderFieldEnum::DATE,
+        Google::Ads::GoogleAds::V4::Enums::AdCustomizerPlaceholderFieldEnum::DATE,
     });
 
   # Create the feed mapping.
-  my $feed_mapping = Google::Ads::GoogleAds::V3::Resources::FeedMapping->new({
+  my $feed_mapping = Google::Ads::GoogleAds::V4::Resources::FeedMapping->new({
       placeholderType => AD_CUSTOMIZER,
       feed            => $ad_customizer_feed_resource_name,
       attributeFieldMappings =>
@@ -223,7 +230,7 @@ sub create_ad_customizer_mapping {
 
   # Create the operation.
   my $feed_mapping_operation =
-    Google::Ads::GoogleAds::V3::Services::FeedMappingService::FeedMappingOperation
+    Google::Ads::GoogleAds::V4::Services::FeedMappingService::FeedMappingOperation
     ->new({
       create => $feed_mapping
     });
@@ -296,31 +303,31 @@ sub create_feed_item_operation {
   ) = @_;
 
   my $name_attribute_value =
-    Google::Ads::GoogleAds::V3::Resources::FeedItemAttributeValue->new({
+    Google::Ads::GoogleAds::V4::Resources::FeedItemAttributeValue->new({
       feedAttributeId => $ad_customizer_feed_attributes->{Name},
       stringValue     => $name
     });
 
   my $price_attribute_value =
-    Google::Ads::GoogleAds::V3::Resources::FeedItemAttributeValue->new({
+    Google::Ads::GoogleAds::V4::Resources::FeedItemAttributeValue->new({
       feedAttributeId => $ad_customizer_feed_attributes->{Price},
       stringValue     => $price
     });
 
   my $date_attribute_value =
-    Google::Ads::GoogleAds::V3::Resources::FeedItemAttributeValue->new({
+    Google::Ads::GoogleAds::V4::Resources::FeedItemAttributeValue->new({
       feedAttributeId => $ad_customizer_feed_attributes->{Date},
       stringValue     => $date
     });
 
-  my $feed_item = Google::Ads::GoogleAds::V3::Resources::FeedItem->new({
+  my $feed_item = Google::Ads::GoogleAds::V4::Resources::FeedItem->new({
       feed => $ad_customizer_feed_resource_name,
       attributeValues =>
         [$name_attribute_value, $price_attribute_value, $date_attribute_value]}
   );
 
   return
-    Google::Ads::GoogleAds::V3::Services::FeedItemService::FeedItemOperation->
+    Google::Ads::GoogleAds::V4::Services::FeedItemService::FeedItemOperation->
     new({
       create => $feed_item
     });
@@ -340,15 +347,15 @@ sub create_feed_item_targets {
     my $ad_group_id             = $ad_group_ids->[$i];
 
     my $feed_item_target =
-      Google::Ads::GoogleAds::V3::Resources::FeedItemTarget->new({
+      Google::Ads::GoogleAds::V4::Resources::FeedItemTarget->new({
         feedItem => $feed_item_resource_name,
-        adGroup  => Google::Ads::GoogleAds::V3::Utils::ResourceNames::ad_group(
+        adGroup  => Google::Ads::GoogleAds::V4::Utils::ResourceNames::ad_group(
           $customer_id, $ad_group_id
         )});
 
     # Create the operation.
     my $feed_item_target_operation =
-      Google::Ads::GoogleAds::V3::Services::FeedItemTargetService::FeedItemTargetOperation
+      Google::Ads::GoogleAds::V4::Services::FeedItemTargetService::FeedItemTargetOperation
       ->new({
         create => $feed_item_target
       });
@@ -371,26 +378,26 @@ sub create_ads_with_customizations {
   my ($api_client, $customer_id, $ad_group_ids, $feed_name) = @_;
 
   my $expanded_text_ad_info =
-    Google::Ads::GoogleAds::V3::Common::ExpandedTextAdInfo->new({
+    Google::Ads::GoogleAds::V4::Common::ExpandedTextAdInfo->new({
       headlinePart1 => "Luxury cruise to {=$feed_name.Name}",
       headlinePart2 => "Only {=$feed_name.Price}",
       description   => "Offer ends in {=countdown($feed_name.Date)}!"
     });
 
-  my $ad = Google::Ads::GoogleAds::V3::Resources::Ad->new({
+  my $ad = Google::Ads::GoogleAds::V4::Resources::Ad->new({
       expandedTextAd => $expanded_text_ad_info,
       finalUrls      => ["http://www.example.com"]});
 
   my $ad_group_ad_operations = [];
   foreach my $ad_group_id (@$ad_group_ids) {
-    my $ad_group_ad = Google::Ads::GoogleAds::V3::Resources::AdGroupAd->new({
+    my $ad_group_ad = Google::Ads::GoogleAds::V4::Resources::AdGroupAd->new({
         ad      => $ad,
-        adGroup => Google::Ads::GoogleAds::V3::Utils::ResourceNames::ad_group(
+        adGroup => Google::Ads::GoogleAds::V4::Utils::ResourceNames::ad_group(
           $customer_id, $ad_group_id
         )});
 
     push @$ad_group_ad_operations,
-      Google::Ads::GoogleAds::V3::Services::AdGroupAdService::AdGroupAdOperation
+      Google::Ads::GoogleAds::V4::Services::AdGroupAdService::AdGroupAdOperation
       ->new({
         create => $ad_group_ad
       });
@@ -416,25 +423,24 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
 
 # Parameters passed on the command line will override any parameters set in code.
 GetOptions(
-  "customer_id=s"   => \$customer_id,
-  "ad_group_id_1=i" => \$ad_group_id_1,
-  "ad_group_id_2=i" => \$ad_group_id_2
+  "customer_id=s"  => \$customer_id,
+  "ad_group_ids=i" => \@$ad_group_ids
 );
+$ad_group_ids = [$ad_group_id_1, $ad_group_id_2] unless @$ad_group_ids;
 
 # Print the help message if the parameters are not initialized in the code nor
 # in the command line.
-pod2usage(2) if not check_params($customer_id, $ad_group_id_1, $ad_group_id_2);
+pod2usage(2) if not check_params($customer_id, $ad_group_ids);
 
 # Call the example.
-add_ad_customizer($api_client, $customer_id =~ s/-//gr,
-  $ad_group_id_1, $ad_group_id_2);
+add_ad_customizer($api_client, $customer_id =~ s/-//gr, $ad_group_ids);
 
 =pod
 
@@ -453,7 +459,6 @@ add_ad_customizer.pl [options]
 
     -help                       Show the help message.
     -customer_id                The Google Ads customer ID.
-    -ad_group_id_1              The ad group ID 1 to bind the feed items to.
-    -ad_group_id_2              The ad group ID 2 to bind the feed items to.
+    -ad_group_ids               The ad group IDs to bind the feed items to.
 
 =cut
