@@ -25,13 +25,13 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Resources::AdGroupAd;
-use Google::Ads::GoogleAds::V3::Resources::Ad;
-use Google::Ads::GoogleAds::V3::Common::ExpandedTextAdInfo;
-use Google::Ads::GoogleAds::V3::Common::CustomParameter;
-use Google::Ads::GoogleAds::V3::Enums::AdGroupAdStatusEnum qw(PAUSED);
-use Google::Ads::GoogleAds::V3::Services::AdGroupAdService::AdGroupAdOperation;
-use Google::Ads::GoogleAds::V3::Utils::ResourceNames;
+use Google::Ads::GoogleAds::V4::Resources::AdGroupAd;
+use Google::Ads::GoogleAds::V4::Resources::Ad;
+use Google::Ads::GoogleAds::V4::Common::ExpandedTextAdInfo;
+use Google::Ads::GoogleAds::V4::Common::CustomParameter;
+use Google::Ads::GoogleAds::V4::Enums::AdGroupAdStatusEnum qw(PAUSED);
+use Google::Ads::GoogleAds::V4::Services::AdGroupAdService::AdGroupAdOperation;
+use Google::Ads::GoogleAds::V4::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -53,19 +53,19 @@ sub add_expanded_text_ad_with_upgraded_urls {
 
   # Create an expanded text ad info.
   my $expanded_text_ad_info =
-    Google::Ads::GoogleAds::V3::Common::ExpandedTextAdInfo->new({
+    Google::Ads::GoogleAds::V4::Common::ExpandedTextAdInfo->new({
       description   => "Low-gravity fun for everyone!",
       headlinePart1 => "Luxury Cruise to Mars",
       headlinePart2 => "Visit the Red Planet in style.",
     });
 
   # Create an ad group ad.
-  my $ad_group_ad = Google::Ads::GoogleAds::V3::Resources::AdGroupAd->new({
-      adGroup => Google::Ads::GoogleAds::V3::Utils::ResourceNames::ad_group(
+  my $ad_group_ad = Google::Ads::GoogleAds::V4::Resources::AdGroupAd->new({
+      adGroup => Google::Ads::GoogleAds::V4::Utils::ResourceNames::ad_group(
         $customer_id, $ad_group_id
       ),
       status => PAUSED,
-      ad     => Google::Ads::GoogleAds::V3::Resources::Ad->new({
+      ad     => Google::Ads::GoogleAds::V4::Resources::Ad->new({
           # Set the expanded text ad info on an ad.
           expandedTextAd => $expanded_text_ad_info,
           # Specify a list of final URLs. This field cannot be set if URL field is set. This
@@ -81,12 +81,12 @@ sub add_expanded_text_ad_with_upgraded_urls {
           # Since your tracking URL has two custom parameters, provide their values too. This can
           # be provided at campaign, ad group, ad, criterion or feed item levels.
           urlCustomParameters => [
-            Google::Ads::GoogleAds::V3::Common::CustomParameter->new({
+            Google::Ads::GoogleAds::V4::Common::CustomParameter->new({
                 key   => "season",
                 value => "christmas"
               }
             ),
-            Google::Ads::GoogleAds::V3::Common::CustomParameter->new({
+            Google::Ads::GoogleAds::V4::Common::CustomParameter->new({
                 key   => "promocode",
                 value => "NY123"
               })
@@ -102,7 +102,7 @@ sub add_expanded_text_ad_with_upgraded_urls {
 
   # Create an ad group ad operation.
   my $ad_group_ad_operation =
-    Google::Ads::GoogleAds::V3::Services::AdGroupAdService::AdGroupAdOperation
+    Google::Ads::GoogleAds::V4::Services::AdGroupAdService::AdGroupAdOperation
     ->new({create => $ad_group_ad});
 
   # Add the ad group ad.
@@ -122,7 +122,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
