@@ -36,30 +36,30 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::MediaUtils;
-use Google::Ads::GoogleAds::V3::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V3::Resources::Campaign;
-use Google::Ads::GoogleAds::V3::Resources::AdGroup;
-use Google::Ads::GoogleAds::V3::Resources::AdGroupAd;
-use Google::Ads::GoogleAds::V3::Resources::Ad;
-use Google::Ads::GoogleAds::V3::Resources::Asset;
-use Google::Ads::GoogleAds::V3::Common::TargetCpa;
-use Google::Ads::GoogleAds::V3::Common::ResponsiveDisplayAdInfo;
-use Google::Ads::GoogleAds::V3::Common::AdTextAsset;
-use Google::Ads::GoogleAds::V3::Common::AdImageAsset;
-use Google::Ads::GoogleAds::V3::Common::ImageAsset;
-use Google::Ads::GoogleAds::V3::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
-use Google::Ads::GoogleAds::V3::Enums::AdvertisingChannelTypeEnum qw(DISPLAY);
-use Google::Ads::GoogleAds::V3::Enums::AdvertisingChannelSubTypeEnum
+use Google::Ads::GoogleAds::V4::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V4::Resources::Campaign;
+use Google::Ads::GoogleAds::V4::Resources::AdGroup;
+use Google::Ads::GoogleAds::V4::Resources::AdGroupAd;
+use Google::Ads::GoogleAds::V4::Resources::Ad;
+use Google::Ads::GoogleAds::V4::Resources::Asset;
+use Google::Ads::GoogleAds::V4::Common::TargetCpa;
+use Google::Ads::GoogleAds::V4::Common::ResponsiveDisplayAdInfo;
+use Google::Ads::GoogleAds::V4::Common::AdTextAsset;
+use Google::Ads::GoogleAds::V4::Common::AdImageAsset;
+use Google::Ads::GoogleAds::V4::Common::ImageAsset;
+use Google::Ads::GoogleAds::V4::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
+use Google::Ads::GoogleAds::V4::Enums::AdvertisingChannelTypeEnum qw(DISPLAY);
+use Google::Ads::GoogleAds::V4::Enums::AdvertisingChannelSubTypeEnum
   qw(DISPLAY_SMART_CAMPAIGN);
-use Google::Ads::GoogleAds::V3::Enums::AdGroupStatusEnum;
-use Google::Ads::GoogleAds::V3::Enums::AdGroupAdStatusEnum;
-use Google::Ads::GoogleAds::V3::Enums::AssetTypeEnum qw(IMAGE);
+use Google::Ads::GoogleAds::V4::Enums::AdGroupStatusEnum;
+use Google::Ads::GoogleAds::V4::Enums::AdGroupAdStatusEnum;
+use Google::Ads::GoogleAds::V4::Enums::AssetTypeEnum qw(IMAGE);
 use
-  Google::Ads::GoogleAds::V3::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V3::Services::CampaignService::CampaignOperation;
-use Google::Ads::GoogleAds::V3::Services::AdGroupService::AdGroupOperation;
-use Google::Ads::GoogleAds::V3::Services::AdGroupAdService::AdGroupAdOperation;
-use Google::Ads::GoogleAds::V3::Services::AssetService::AssetOperation;
+  Google::Ads::GoogleAds::V4::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V4::Services::CampaignService::CampaignOperation;
+use Google::Ads::GoogleAds::V4::Services::AdGroupService::AdGroupOperation;
+use Google::Ads::GoogleAds::V4::Services::AdGroupAdService::AdGroupAdOperation;
+use Google::Ads::GoogleAds::V4::Services::AssetService::AssetOperation;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -117,7 +117,7 @@ sub create_campaign_budget {
 
   # Create a campaign budget.
   my $campaign_budget =
-    Google::Ads::GoogleAds::V3::Resources::CampaignBudget->new({
+    Google::Ads::GoogleAds::V4::Resources::CampaignBudget->new({
       name           => "Interplanetary Cruise Budget #" . uniqid(),
       deliveryMethod => STANDARD,
       amountMicros   => 5000000
@@ -125,7 +125,7 @@ sub create_campaign_budget {
 
   # Create a campaign budget operation.
   my $campaign_budget_operation =
-    Google::Ads::GoogleAds::V3::Services::CampaignBudgetService::CampaignBudgetOperation
+    Google::Ads::GoogleAds::V4::Services::CampaignBudgetService::CampaignBudgetOperation
     ->new({
       create => $campaign_budget
     });
@@ -147,7 +147,7 @@ sub create_campaign_budget {
 sub create_smart_display_campaign {
   my ($api_client, $customer_id, $campaign_budget_resource_name) = @_;
 
-  my $campaign = Google::Ads::GoogleAds::V3::Resources::Campaign->new({
+  my $campaign = Google::Ads::GoogleAds::V4::Resources::Campaign->new({
       name => "Smart Display Campaign #" . uniqid(),
       # Smart Display campaign requires the advertising_channel_type as 'DISPLAY'.
       advertisingChannelType => DISPLAY,
@@ -155,7 +155,7 @@ sub create_smart_display_campaign {
       # 'DISPLAY_SMART_CAMPAIGN'.
       advertisingChannelSubType => DISPLAY_SMART_CAMPAIGN,
       # Smart Display campaign requires the TargetCpa bidding strategy.
-      targetCpa => Google::Ads::GoogleAds::V3::Common::TargetCpa->new({
+      targetCpa => Google::Ads::GoogleAds::V4::Common::TargetCpa->new({
           targetCpaMicros => 5000000
         }
       ),
@@ -168,7 +168,7 @@ sub create_smart_display_campaign {
 
   # Create a campaign operation.
   my $campaign_operation =
-    Google::Ads::GoogleAds::V3::Services::CampaignService::CampaignOperation->
+    Google::Ads::GoogleAds::V4::Services::CampaignService::CampaignOperation->
     new({
       create => $campaign
     });
@@ -192,15 +192,15 @@ sub create_ad_group {
   my ($api_client, $customer_id, $campaign_resource_name) = @_;
 
   # Construct an ad group and set its type.
-  my $ad_group = Google::Ads::GoogleAds::V3::Resources::AdGroup->new({
+  my $ad_group = Google::Ads::GoogleAds::V4::Resources::AdGroup->new({
     name     => "Earth to Mars Cruises #" . uniqid(),
     campaign => $campaign_resource_name,
-    status   => Google::Ads::GoogleAds::V3::Enums::AdGroupStatusEnum::PAUSED
+    status   => Google::Ads::GoogleAds::V4::Enums::AdGroupStatusEnum::PAUSED
   });
 
   # Create an ad group operation.
   my $ad_group_operation =
-    Google::Ads::GoogleAds::V3::Services::AdGroupService::AdGroupOperation->new(
+    Google::Ads::GoogleAds::V4::Services::AdGroupService::AdGroupOperation->new(
     {
       create => $ad_group
     });
@@ -241,19 +241,19 @@ sub create_responsive_display_ad {
 
   # Create a responsive display ad info.
   my $responsive_display_ad_info =
-    Google::Ads::GoogleAds::V3::Common::ResponsiveDisplayAdInfo->new({
+    Google::Ads::GoogleAds::V4::Common::ResponsiveDisplayAdInfo->new({
       # Set some basic required information for the responsive display ad.
       headlines => [
-        Google::Ads::GoogleAds::V3::Common::AdTextAsset->new({
+        Google::Ads::GoogleAds::V4::Common::AdTextAsset->new({
             text => "Travel"
           })
       ],
-      longHeadline => Google::Ads::GoogleAds::V3::Common::AdTextAsset->new({
+      longHeadline => Google::Ads::GoogleAds::V4::Common::AdTextAsset->new({
           text => "Travel the World"
         }
       ),
       descriptions => [
-        Google::Ads::GoogleAds::V3::Common::AdTextAsset->new({
+        Google::Ads::GoogleAds::V4::Common::AdTextAsset->new({
             text => "Take to the air!"
           })
       ],
@@ -261,12 +261,12 @@ sub create_responsive_display_ad {
       # Set the marketing image and square marketing image to the previously
       # created image assets.
       marketingImages => [
-        Google::Ads::GoogleAds::V3::Common::AdImageAsset->new({
+        Google::Ads::GoogleAds::V4::Common::AdImageAsset->new({
             asset => $marketing_image_asset_resource_name
           })
       ],
       squareMarketingImages => [
-        Google::Ads::GoogleAds::V3::Common::AdImageAsset->new({
+        Google::Ads::GoogleAds::V4::Common::AdImageAsset->new({
             asset => $square_marketing_image_asset_resource_name
           })
       ],
@@ -277,17 +277,17 @@ sub create_responsive_display_ad {
     });
 
   # Create an ad group ad with the created responsive display ad info.
-  my $ad_group_ad = Google::Ads::GoogleAds::V3::Resources::AdGroupAd->new({
+  my $ad_group_ad = Google::Ads::GoogleAds::V4::Resources::AdGroupAd->new({
       adGroup => $ad_group_resource_name,
-      status  => Google::Ads::GoogleAds::V3::Enums::AdGroupAdStatusEnum::PAUSED,
-      ad      => Google::Ads::GoogleAds::V3::Resources::Ad->new({
+      status  => Google::Ads::GoogleAds::V4::Enums::AdGroupAdStatusEnum::PAUSED,
+      ad      => Google::Ads::GoogleAds::V4::Resources::Ad->new({
           finalUrls           => ["https://www.example.com"],
           responsiveDisplayAd => $responsive_display_ad_info
         })});
 
   # Create an ad group ad operation.
   my $ad_group_ad_operation =
-    Google::Ads::GoogleAds::V3::Services::AdGroupAdService::AdGroupAdOperation
+    Google::Ads::GoogleAds::V4::Services::AdGroupAdService::AdGroupAdOperation
     ->new({
       create => $ad_group_ad
     });
@@ -307,16 +307,16 @@ sub create_responsive_display_ad {
 sub create_image_asset {
   my ($api_client, $customer_id, $image_url, $image_name) = @_;
 
-  # Create a media file.
-  my $asset = Google::Ads::GoogleAds::V3::Resources::Asset->new({
+  # Create an asset.
+  my $asset = Google::Ads::GoogleAds::V4::Resources::Asset->new({
       name       => $image_name,
       type       => IMAGE,
-      imageAsset => Google::Ads::GoogleAds::V3::Common::ImageAsset->new({
+      imageAsset => Google::Ads::GoogleAds::V4::Common::ImageAsset->new({
           data => get_base64_data_from_url($image_url)})});
 
   # Create an asset operation.
   my $asset_operation =
-    Google::Ads::GoogleAds::V3::Services::AssetService::AssetOperation->new({
+    Google::Ads::GoogleAds::V4::Services::AssetService::AssetOperation->new({
       create => $asset
     });
 
@@ -339,7 +339,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
