@@ -26,10 +26,10 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::FieldMasks;
-use Google::Ads::GoogleAds::V3::Resources::Ad;
-use Google::Ads::GoogleAds::V3::Common::ExpandedTextAdInfo;
-use Google::Ads::GoogleAds::V3::Services::AdService::AdOperation;
-use Google::Ads::GoogleAds::V3::Utils::ResourceNames;
+use Google::Ads::GoogleAds::V4::Resources::Ad;
+use Google::Ads::GoogleAds::V4::Common::ExpandedTextAdInfo;
+use Google::Ads::GoogleAds::V4::Services::AdService::AdOperation;
+use Google::Ads::GoogleAds::V4::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -51,12 +51,12 @@ sub update_expanded_text_ad {
   my ($api_client, $customer_id, $ad_id) = @_;
 
   # Create an ad with the proper resource name and any other changes.
-  my $ad = Google::Ads::GoogleAds::V3::Resources::Ad->new({
-      resourceName => Google::Ads::GoogleAds::V3::Utils::ResourceNames::ad(
+  my $ad = Google::Ads::GoogleAds::V4::Resources::Ad->new({
+      resourceName => Google::Ads::GoogleAds::V4::Utils::ResourceNames::ad(
         $customer_id, $ad_id
       ),
       expandedTextAd =>
-        Google::Ads::GoogleAds::V3::Common::ExpandedTextAdInfo->new({
+        Google::Ads::GoogleAds::V4::Common::ExpandedTextAdInfo->new({
           # Update some properties of the expanded text ad.
           headlinePart1 => "Cruise to Pluto #" . uniqid(),
           headlinePart2 => "Tickets on sale now",
@@ -69,7 +69,7 @@ sub update_expanded_text_ad {
   # Create an ad operation for update, using the FieldMasks utility to derive
   # the update mask.
   my $ad_operation =
-    Google::Ads::GoogleAds::V3::Services::AdService::AdOperation->new({
+    Google::Ads::GoogleAds::V4::Services::AdService::AdOperation->new({
       update     => $ad,
       updateMask => all_set_fields_of($ad)});
 
@@ -90,7 +90,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
