@@ -29,13 +29,13 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Resources::AdGroupCriterion;
-use Google::Ads::GoogleAds::V3::Common::KeywordInfo;
-use Google::Ads::GoogleAds::V3::Enums::KeywordMatchTypeEnum qw(EXACT);
-use Google::Ads::GoogleAds::V3::Enums::AdGroupCriterionStatusEnum qw(ENABLED);
+use Google::Ads::GoogleAds::V4::Resources::AdGroupCriterion;
+use Google::Ads::GoogleAds::V4::Common::KeywordInfo;
+use Google::Ads::GoogleAds::V4::Enums::KeywordMatchTypeEnum qw(EXACT);
+use Google::Ads::GoogleAds::V4::Enums::AdGroupCriterionStatusEnum qw(ENABLED);
 use
-  Google::Ads::GoogleAds::V3::Services::AdGroupCriterionService::AdGroupCriterionOperation;
-use Google::Ads::GoogleAds::V3::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V4::Services::AdGroupCriterionService::AdGroupCriterionOperation;
+use Google::Ads::GoogleAds::V4::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -130,15 +130,15 @@ sub create_ad_group_criterion_operations {
   my $operations = [];
   for (my $i = 0 ; $i < NUM_KEYWORDS ; $i++) {
     # Create a keyword info.
-    my $keyword_info = Google::Ads::GoogleAds::V3::Common::KeywordInfo->new({
+    my $keyword_info = Google::Ads::GoogleAds::V4::Common::KeywordInfo->new({
       text      => "mars cruise req " . $request_index . " seed " . $i,
       matchType => EXACT
     });
 
     # Construct an ad group criterion using the keyword text info above.
     my $ad_group_criterion =
-      Google::Ads::GoogleAds::V3::Resources::AdGroupCriterion->new({
-        adGroup => Google::Ads::GoogleAds::V3::Utils::ResourceNames::ad_group(
+      Google::Ads::GoogleAds::V4::Resources::AdGroupCriterion->new({
+        adGroup => Google::Ads::GoogleAds::V4::Utils::ResourceNames::ad_group(
           $customer_id, $ad_group_id
         ),
         status  => ENABLED,
@@ -147,7 +147,7 @@ sub create_ad_group_criterion_operations {
 
     # Create an ad group criterion operation.
     my $ad_group_criterion_operation =
-      Google::Ads::GoogleAds::V3::Services::AdGroupCriterionService::AdGroupCriterionOperation
+      Google::Ads::GoogleAds::V4::Services::AdGroupCriterionService::AdGroupCriterionOperation
       ->new({
         create => $ad_group_criterion
       });
@@ -190,7 +190,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(0);
