@@ -27,23 +27,23 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::SearchStreamHandler;
-use Google::Ads::GoogleAds::V3::Resources::Feed;
-use Google::Ads::GoogleAds::V3::Resources::AffiliateLocationFeedData;
-use Google::Ads::GoogleAds::V3::Resources::CampaignFeed;
-use Google::Ads::GoogleAds::V3::Common::MatchingFunction;
-use Google::Ads::GoogleAds::V3::Enums::AffiliateLocationFeedRelationshipTypeEnum
+use Google::Ads::GoogleAds::V4::Resources::Feed;
+use Google::Ads::GoogleAds::V4::Resources::AffiliateLocationFeedData;
+use Google::Ads::GoogleAds::V4::Resources::CampaignFeed;
+use Google::Ads::GoogleAds::V4::Common::MatchingFunction;
+use Google::Ads::GoogleAds::V4::Enums::AffiliateLocationFeedRelationshipTypeEnum
   qw(GENERAL_RETAILER);
-use Google::Ads::GoogleAds::V3::Enums::FeedOriginEnum qw(GOOGLE);
-use Google::Ads::GoogleAds::V3::Enums::PlaceholderTypeEnum
+use Google::Ads::GoogleAds::V4::Enums::FeedOriginEnum qw(GOOGLE);
+use Google::Ads::GoogleAds::V4::Enums::PlaceholderTypeEnum
   qw(AFFILIATE_LOCATION);
-use Google::Ads::GoogleAds::V3::Enums::AffiliateLocationPlaceholderFieldEnum
+use Google::Ads::GoogleAds::V4::Enums::AffiliateLocationPlaceholderFieldEnum
   qw(CHAIN_ID);
 use
-  Google::Ads::GoogleAds::V3::Services::CustomerFeedService::CustomerFeedOperation;
-use Google::Ads::GoogleAds::V3::Services::FeedService::FeedOperation;
+  Google::Ads::GoogleAds::V4::Services::CustomerFeedService::CustomerFeedOperation;
+use Google::Ads::GoogleAds::V4::Services::FeedService::FeedOperation;
 use
-  Google::Ads::GoogleAds::V3::Services::CampaignFeedService::CampaignFeedOperation;
-use Google::Ads::GoogleAds::V3::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V4::Services::CampaignFeedService::CampaignFeedOperation;
+use Google::Ads::GoogleAds::V4::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -163,7 +163,7 @@ sub remove_customer_feeds {
   my $operations = [];
   foreach my $customer_feed (@$customer_feeds) {
     push @$operations,
-      Google::Ads::GoogleAds::V3::Services::CustomerFeedService::CustomerFeedOperation
+      Google::Ads::GoogleAds::V4::Services::CustomerFeedService::CustomerFeedOperation
       ->new({remove => $customer_feed->{resourceName}});
   }
 
@@ -210,7 +210,7 @@ sub remove_feeds {
   my $operations = [];
   foreach my $feed (@$feeds) {
     push @$operations,
-      Google::Ads::GoogleAds::V3::Services::FeedService::FeedOperation->new(
+      Google::Ads::GoogleAds::V4::Services::FeedService::FeedOperation->new(
       {remove => $feed->{resourceName}});
   }
 
@@ -228,10 +228,10 @@ sub create_affiliate_location_extension_feed {
   # Create a feed that will sync to retail addresses for a given retail chain ID.
   # Do not add feed attributes, Google Ads will add them automatically because
   # this will be a system generated feed.
-  my $feed = Google::Ads::GoogleAds::V3::Resources::Feed->new({
+  my $feed = Google::Ads::GoogleAds::V4::Resources::Feed->new({
       name => "Affiliate Location Extension feed #" . uniqid(),
       affiliateLocationFeedData =>
-        Google::Ads::GoogleAds::V3::Resources::AffiliateLocationFeedData->new({
+        Google::Ads::GoogleAds::V4::Resources::AffiliateLocationFeedData->new({
           chainIds         => [$chain_id],
           relationshipType => GENERAL_RETAILER
         }
@@ -243,7 +243,7 @@ sub create_affiliate_location_extension_feed {
 
   # Create the feed operation.
   my $operation =
-    Google::Ads::GoogleAds::V3::Services::FeedService::FeedOperation->new({
+    Google::Ads::GoogleAds::V4::Services::FeedService::FeedOperation->new({
       create => $feed
     });
 
@@ -333,21 +333,21 @@ sub create_campaign_feed {
 
   # Add a campaign feed that associates the feed with this campaign for the
   # AFFILIATE_LOCATION placeholder type.
-  my $campaign_feed = Google::Ads::GoogleAds::V3::Resources::CampaignFeed->new({
+  my $campaign_feed = Google::Ads::GoogleAds::V4::Resources::CampaignFeed->new({
       feed             => $feed_resource_name,
       placeholderTypes => AFFILIATE_LOCATION,
       matchingFunction =>
-        Google::Ads::GoogleAds::V3::Common::MatchingFunction->new({
+        Google::Ads::GoogleAds::V4::Common::MatchingFunction->new({
           functionString => $matching_function
         }
         ),
-      campaign => Google::Ads::GoogleAds::V3::Utils::ResourceNames::campaign(
+      campaign => Google::Ads::GoogleAds::V4::Utils::ResourceNames::campaign(
         $customer_id, $campaign_id
       )});
 
   # Create the campaign feed operation.
   my $operation =
-    Google::Ads::GoogleAds::V3::Services::CampaignFeedService::CampaignFeedOperation
+    Google::Ads::GoogleAds::V4::Services::CampaignFeedService::CampaignFeedOperation
     ->new({
       create => $campaign_feed
     });
@@ -381,7 +381,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
