@@ -26,20 +26,20 @@ use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Constants;
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Resources::Feed;
-use Google::Ads::GoogleAds::V3::Resources::PlacesLocationFeedData;
-use Google::Ads::GoogleAds::V3::Resources::OAuthInfo;
-use Google::Ads::GoogleAds::V3::Resources::CustomerFeed;
-use Google::Ads::GoogleAds::V3::Common::MatchingFunction;
-use Google::Ads::GoogleAds::V3::Common::Operand;
-use Google::Ads::GoogleAds::V3::Common::ConstantOperand;
-use Google::Ads::GoogleAds::V3::Enums::FeedOriginEnum qw(GOOGLE);
-use Google::Ads::GoogleAds::V3::Enums::PlaceholderTypeEnum qw(LOCATION);
-use Google::Ads::GoogleAds::V3::Enums::MatchingFunctionOperatorEnum
+use Google::Ads::GoogleAds::V4::Resources::Feed;
+use Google::Ads::GoogleAds::V4::Resources::PlacesLocationFeedData;
+use Google::Ads::GoogleAds::V4::Resources::OAuthInfo;
+use Google::Ads::GoogleAds::V4::Resources::CustomerFeed;
+use Google::Ads::GoogleAds::V4::Common::MatchingFunction;
+use Google::Ads::GoogleAds::V4::Common::Operand;
+use Google::Ads::GoogleAds::V4::Common::ConstantOperand;
+use Google::Ads::GoogleAds::V4::Enums::FeedOriginEnum qw(GOOGLE);
+use Google::Ads::GoogleAds::V4::Enums::PlaceholderTypeEnum qw(LOCATION);
+use Google::Ads::GoogleAds::V4::Enums::MatchingFunctionOperatorEnum
   qw(IDENTITY);
-use Google::Ads::GoogleAds::V3::Services::FeedService::FeedOperation;
+use Google::Ads::GoogleAds::V4::Services::FeedService::FeedOperation;
 use
-  Google::Ads::GoogleAds::V3::Services::CustomerFeedService::CustomerFeedOperation;
+  Google::Ads::GoogleAds::V4::Services::CustomerFeedService::CustomerFeedOperation;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -70,11 +70,11 @@ sub add_google_my_business_location_extensions {
   # Create a feed that will sync to the Google My Business account specified by
   # $gmb_email_address. Do not add FeedAttributes to this object as Google Ads
   # will add them automatically because this will be a system generated feed.
-  my $gmb_feed = Google::Ads::GoogleAds::V3::Resources::Feed->new({
+  my $gmb_feed = Google::Ads::GoogleAds::V4::Resources::Feed->new({
       name => "Google My Business feed #" . uniqid(),
       # Configure the location feed populated from Google My Business Locations.
       placesLocationFeedData =>
-        Google::Ads::GoogleAds::V3::Resources::PlacesLocationFeedData->new({
+        Google::Ads::GoogleAds::V4::Resources::PlacesLocationFeedData->new({
           emailAddress      => $gmb_email_address,
           businessAccountId => $business_account_id,
           # Used to filter Google My Business listings by labels. If entries exist in
@@ -84,7 +84,7 @@ sub add_google_my_business_location_extensions {
           labelFilters => ["Stores in New York"],
           # Set the authentication info to be able to connect Google Ads to the GMB
           # account.
-          oauthInfo => Google::Ads::GoogleAds::V3::Resources::OAuthInfo->new({
+          oauthInfo => Google::Ads::GoogleAds::V4::Resources::OAuthInfo->new({
               httpMethod => "GET",
               httpRequestUrl =>
                 Google::Ads::GoogleAds::Constants::DEFAULT_OAUTH2_SCOPE,
@@ -98,7 +98,7 @@ sub add_google_my_business_location_extensions {
 
   # Create a feed operation.
   my $feed_operation =
-    Google::Ads::GoogleAds::V3::Services::FeedService::FeedOperation->new(
+    Google::Ads::GoogleAds::V4::Services::FeedService::FeedOperation->new(
     {create => $gmb_feed});
 
   # Add the feed. Since it is a system generated feed, Google Ads will automatically:
@@ -115,16 +115,16 @@ sub add_google_my_business_location_extensions {
 
   # Add a CustomerFeed that associates the feed with this customer for the LOCATION
   # placeholder type.
-  my $customer_feed = Google::Ads::GoogleAds::V3::Resources::CustomerFeed->new({
+  my $customer_feed = Google::Ads::GoogleAds::V4::Resources::CustomerFeed->new({
       feed             => $feed_resource_name,
       placeholderTypes => LOCATION,
       # Create a matching function that will always evaluate to true.
       matchingFunction =>
-        Google::Ads::GoogleAds::V3::Common::MatchingFunction->new({
+        Google::Ads::GoogleAds::V4::Common::MatchingFunction->new({
           leftOperands => [
-            Google::Ads::GoogleAds::V3::Common::Operand->new({
+            Google::Ads::GoogleAds::V4::Common::Operand->new({
                 constantOperand =>
-                  Google::Ads::GoogleAds::V3::Common::ConstantOperand->new({
+                  Google::Ads::GoogleAds::V4::Common::ConstantOperand->new({
                     booleanValue => "true"
                   })})
           ],
@@ -134,7 +134,7 @@ sub add_google_my_business_location_extensions {
 
   # Create a customer feed operation.
   my $customer_feed_operation =
-    Google::Ads::GoogleAds::V3::Services::CustomerFeedService::CustomerFeedOperation
+    Google::Ads::GoogleAds::V4::Services::CustomerFeedService::CustomerFeedOperation
     ->new({create => $customer_feed});
 
   # After the completion of the Feed ADD operation above the added feed will not be available
@@ -200,7 +200,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
