@@ -30,26 +30,26 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V3::Resources::Campaign;
-use Google::Ads::GoogleAds::V3::Resources::HotelSettingInfo;
-use Google::Ads::GoogleAds::V3::Resources::NetworkSettings;
-use Google::Ads::GoogleAds::V3::Resources::AdGroup;
-use Google::Ads::GoogleAds::V3::Resources::AdGroupAd;
-use Google::Ads::GoogleAds::V3::Resources::Ad;
-use Google::Ads::GoogleAds::V3::Common::PercentCpc;
-use Google::Ads::GoogleAds::V3::Common::HotelAdInfo;
-use Google::Ads::GoogleAds::V3::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
-use Google::Ads::GoogleAds::V3::Enums::AdvertisingChannelTypeEnum qw(HOTEL);
-use Google::Ads::GoogleAds::V3::Enums::AdGroupTypeEnum qw(HOTEL_ADS);
-use Google::Ads::GoogleAds::V3::Enums::CampaignStatusEnum;
-use Google::Ads::GoogleAds::V3::Enums::AdGroupStatusEnum;
-use Google::Ads::GoogleAds::V3::Enums::AdGroupAdStatusEnum;
+use Google::Ads::GoogleAds::V4::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V4::Resources::Campaign;
+use Google::Ads::GoogleAds::V4::Resources::HotelSettingInfo;
+use Google::Ads::GoogleAds::V4::Resources::NetworkSettings;
+use Google::Ads::GoogleAds::V4::Resources::AdGroup;
+use Google::Ads::GoogleAds::V4::Resources::AdGroupAd;
+use Google::Ads::GoogleAds::V4::Resources::Ad;
+use Google::Ads::GoogleAds::V4::Common::PercentCpc;
+use Google::Ads::GoogleAds::V4::Common::HotelAdInfo;
+use Google::Ads::GoogleAds::V4::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
+use Google::Ads::GoogleAds::V4::Enums::AdvertisingChannelTypeEnum qw(HOTEL);
+use Google::Ads::GoogleAds::V4::Enums::AdGroupTypeEnum qw(HOTEL_ADS);
+use Google::Ads::GoogleAds::V4::Enums::CampaignStatusEnum;
+use Google::Ads::GoogleAds::V4::Enums::AdGroupStatusEnum;
+use Google::Ads::GoogleAds::V4::Enums::AdGroupAdStatusEnum;
 use
-  Google::Ads::GoogleAds::V3::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V3::Services::CampaignService::CampaignOperation;
-use Google::Ads::GoogleAds::V3::Services::AdGroupService::AdGroupOperation;
-use Google::Ads::GoogleAds::V3::Services::AdGroupAdService::AdGroupAdOperation;
+  Google::Ads::GoogleAds::V4::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V4::Services::CampaignService::CampaignOperation;
+use Google::Ads::GoogleAds::V4::Services::AdGroupService::AdGroupOperation;
+use Google::Ads::GoogleAds::V4::Services::AdGroupAdService::AdGroupAdOperation;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -106,7 +106,7 @@ sub add_campaign_budget {
 
   # Create a campaign budget.
   my $campaign_budget =
-    Google::Ads::GoogleAds::V3::Resources::CampaignBudget->new({
+    Google::Ads::GoogleAds::V4::Resources::CampaignBudget->new({
       name           => "Interplanetary Cruise Budget #" . uniqid(),
       deliveryMethod => STANDARD,
       # Set the amount of budget.
@@ -117,7 +117,7 @@ sub add_campaign_budget {
 
   # Create a campaign budget operation.
   my $campaign_budget_operation =
-    Google::Ads::GoogleAds::V3::Services::CampaignBudgetService::CampaignBudgetOperation
+    Google::Ads::GoogleAds::V4::Services::CampaignBudgetService::CampaignBudgetOperation
     ->new({create => $campaign_budget});
 
   # Add the campaign budget.
@@ -139,23 +139,23 @@ sub add_hotel_campaign {
     = @_;
 
   # Create a hotel campaign.
-  my $campaign = Google::Ads::GoogleAds::V3::Resources::Campaign->new({
+  my $campaign = Google::Ads::GoogleAds::V4::Resources::Campaign->new({
       name => "Interplanetary Cruise Campaign #" . uniqid(),
       # Configure settings related to hotel campaigns including advertising
       # channel type and hotel setting info.
       advertisingChannelType => HOTEL,
       hotelSetting =>
-        Google::Ads::GoogleAds::V3::Resources::HotelSettingInfo->new({
+        Google::Ads::GoogleAds::V4::Resources::HotelSettingInfo->new({
           hotelCenterId => $hotel_center_account_id
         }
         ),
       # Recommendation: Set the campaign to PAUSED when creating it to prevent
       # the ads from immediately serving. Set to ENABLED once you've added
       # targeting and the ads are ready to serve.
-      status => Google::Ads::GoogleAds::V3::Enums::CampaignStatusEnum::PAUSED,
+      status => Google::Ads::GoogleAds::V4::Enums::CampaignStatusEnum::PAUSED,
       # Set the bidding strategy to PercentCpc. Only Manual CPC and Percent CPC
       # can be used for hotel campaigns.
-      percentCpc => Google::Ads::GoogleAds::V3::Common::PercentCpc->new(
+      percentCpc => Google::Ads::GoogleAds::V4::Common::PercentCpc->new(
         {cpcBidCeilingMicros => $cpc_bid_ceiling_micro_amount}
       ),
       # Set the budget.
@@ -163,13 +163,13 @@ sub add_hotel_campaign {
       # Configure the campaign network options. Only Google Search is allowed for
       # hotel campaigns.
       networkSettings =>
-        Google::Ads::GoogleAds::V3::Resources::NetworkSettings->new({
+        Google::Ads::GoogleAds::V4::Resources::NetworkSettings->new({
           targetGoogleSearch => "true"
         })});
 
   # Create a campaign operation.
   my $campaign_operation =
-    Google::Ads::GoogleAds::V3::Services::CampaignService::CampaignOperation->
+    Google::Ads::GoogleAds::V4::Services::CampaignService::CampaignOperation->
     new({create => $campaign});
 
   # Add the campaign.
@@ -188,7 +188,7 @@ sub add_hotel_ad_group {
   my ($api_client, $customer_id, $campaign_resource_name) = @_;
 
   # Create an ad group.
-  my $ad_group = Google::Ads::GoogleAds::V3::Resources::AdGroup->new({
+  my $ad_group = Google::Ads::GoogleAds::V4::Resources::AdGroup->new({
     name => "Earth to Mars Cruise #" . uniqid(),
     # Set the campaign.
     campaign => $campaign_resource_name,
@@ -196,12 +196,12 @@ sub add_hotel_ad_group {
     # This cannot be set to other types.
     type         => HOTEL_ADS,
     cpcBidMicros => 1000000,
-    status => Google::Ads::GoogleAds::V3::Enums::AdGroupStatusEnum::ENABLED
+    status => Google::Ads::GoogleAds::V4::Enums::AdGroupStatusEnum::ENABLED
   });
 
   # Create an ad group operation.
   my $ad_group_operation =
-    Google::Ads::GoogleAds::V3::Services::AdGroupService::AdGroupOperation->
+    Google::Ads::GoogleAds::V4::Services::AdGroupService::AdGroupOperation->
     new({create => $ad_group});
 
   # Add the ad group.
@@ -220,19 +220,19 @@ sub add_hotel_ad_group_ad {
   my ($api_client, $customer_id, $ad_group_resource_name) = @_;
 
   # Create an ad group ad and set a hotel ad to it.
-  my $ad_group_ad = Google::Ads::GoogleAds::V3::Resources::AdGroupAd->new({
+  my $ad_group_ad = Google::Ads::GoogleAds::V4::Resources::AdGroupAd->new({
       # Set the ad group.
       adGroup => $ad_group_resource_name,
       # Set the ad to a new shopping product ad.
-      ad => Google::Ads::GoogleAds::V3::Resources::Ad->new({
-          hotelAd => Google::Ads::GoogleAds::V3::Common::HotelAdInfo->new()}
+      ad => Google::Ads::GoogleAds::V4::Resources::Ad->new({
+          hotelAd => Google::Ads::GoogleAds::V4::Common::HotelAdInfo->new()}
       ),
-      status => Google::Ads::GoogleAds::V3::Enums::AdGroupAdStatusEnum::ENABLED
+      status => Google::Ads::GoogleAds::V4::Enums::AdGroupAdStatusEnum::ENABLED
     });
 
   # Create an ad group ad operation.
   my $ad_group_ad_operation =
-    Google::Ads::GoogleAds::V3::Services::AdGroupAdService::AdGroupAdOperation
+    Google::Ads::GoogleAds::V4::Services::AdGroupAdService::AdGroupAdOperation
     ->new({create => $ad_group_ad});
 
   # Add the ad group ad.
@@ -252,7 +252,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
