@@ -25,13 +25,13 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Resources::AdGroupBidModifier;
-use Google::Ads::GoogleAds::V3::Common::HotelCheckInDayInfo;
-use Google::Ads::GoogleAds::V3::Common::HotelLengthOfStayInfo;
-use Google::Ads::GoogleAds::V3::Enums::DayOfWeekEnum qw(MONDAY);
+use Google::Ads::GoogleAds::V4::Resources::AdGroupBidModifier;
+use Google::Ads::GoogleAds::V4::Common::HotelCheckInDayInfo;
+use Google::Ads::GoogleAds::V4::Common::HotelLengthOfStayInfo;
+use Google::Ads::GoogleAds::V4::Enums::DayOfWeekEnum qw(MONDAY);
 use
-  Google::Ads::GoogleAds::V3::Services::AdGroupBidModifierService::AdGroupBidModifierOperation;
-use Google::Ads::GoogleAds::V3::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V4::Services::AdGroupBidModifierService::AdGroupBidModifierOperation;
+use Google::Ads::GoogleAds::V4::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -53,13 +53,13 @@ sub add_hotel_ad_group_bid_modifiers {
 
   # 1) Create an ad group bid modifier based on the hotel check-in day.
   my $check_in_day_ad_group_bid_modifier =
-    Google::Ads::GoogleAds::V3::Resources::AdGroupBidModifier->new({
+    Google::Ads::GoogleAds::V4::Resources::AdGroupBidModifier->new({
       # Set the ad group.
-      adGroup => Google::Ads::GoogleAds::V3::Utils::ResourceNames::ad_group(
+      adGroup => Google::Ads::GoogleAds::V4::Utils::ResourceNames::ad_group(
         $customer_id, $ad_group_id
       ),
       hotelCheckInDay =>
-        Google::Ads::GoogleAds::V3::Common::HotelCheckInDayInfo->new({
+        Google::Ads::GoogleAds::V4::Common::HotelCheckInDayInfo->new({
           dayOfWeek => MONDAY
         }
         ),
@@ -69,21 +69,21 @@ sub add_hotel_ad_group_bid_modifiers {
 
   # Create an ad group bid modifier operation.
   my $check_in_day_ad_group_bid_modifier_operation =
-    Google::Ads::GoogleAds::V3::Services::AdGroupBidModifierService::AdGroupBidModifierOperation
+    Google::Ads::GoogleAds::V4::Services::AdGroupBidModifierService::AdGroupBidModifierOperation
     ->new({
       create => $check_in_day_ad_group_bid_modifier
     });
 
   # 2) Create an ad group bid modifier based on the hotel length of stay.
   my $length_of_stay_ad_group_bid_modifier =
-    Google::Ads::GoogleAds::V3::Resources::AdGroupBidModifier->new({
+    Google::Ads::GoogleAds::V4::Resources::AdGroupBidModifier->new({
       # Set the ad group.
-      adGroup => Google::Ads::GoogleAds::V3::Utils::ResourceNames::ad_group(
+      adGroup => Google::Ads::GoogleAds::V4::Utils::ResourceNames::ad_group(
         $customer_id, $ad_group_id
       ),
       # Create the hotel length of stay info.
       hotelLengthOfStay =>
-        Google::Ads::GoogleAds::V3::Common::HotelLengthOfStayInfo->new({
+        Google::Ads::GoogleAds::V4::Common::HotelLengthOfStayInfo->new({
           minNights => 3,
           maxNights => 7
         }
@@ -94,7 +94,7 @@ sub add_hotel_ad_group_bid_modifiers {
 
   # Create an ad group bid modifier operation.
   my $length_of_stay_ad_group_bid_modifier_operation =
-    Google::Ads::GoogleAds::V3::Services::AdGroupBidModifierService::AdGroupBidModifierOperation
+    Google::Ads::GoogleAds::V4::Services::AdGroupBidModifierService::AdGroupBidModifierOperation
     ->new({
       create => $length_of_stay_ad_group_bid_modifier
     });
@@ -127,7 +127,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
