@@ -25,30 +25,29 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Resources::KeywordPlan;
-use Google::Ads::GoogleAds::V3::Resources::KeywordPlanForecastPeriod;
-use Google::Ads::GoogleAds::V3::Resources::KeywordPlanCampaign;
-use Google::Ads::GoogleAds::V3::Resources::KeywordPlanGeoTarget;
-use Google::Ads::GoogleAds::V3::Resources::KeywordPlanAdGroup;
-use Google::Ads::GoogleAds::V3::Resources::KeywordPlanKeyword;
-use Google::Ads::GoogleAds::V3::Resources::KeywordPlanNegativeKeyword;
-use Google::Ads::GoogleAds::V3::Enums::KeywordPlanForecastIntervalEnum
+use Google::Ads::GoogleAds::V4::Resources::KeywordPlan;
+use Google::Ads::GoogleAds::V4::Resources::KeywordPlanForecastPeriod;
+use Google::Ads::GoogleAds::V4::Resources::KeywordPlanCampaign;
+use Google::Ads::GoogleAds::V4::Resources::KeywordPlanGeoTarget;
+use Google::Ads::GoogleAds::V4::Resources::KeywordPlanAdGroup;
+use Google::Ads::GoogleAds::V4::Resources::KeywordPlanAdGroupKeyword;
+use Google::Ads::GoogleAds::V4::Resources::KeywordPlanCampaignKeyword;
+use Google::Ads::GoogleAds::V4::Enums::KeywordPlanForecastIntervalEnum
   qw(NEXT_QUARTER);
-use Google::Ads::GoogleAds::V3::Enums::KeywordPlanNetworkEnum qw(GOOGLE_SEARCH);
-use Google::Ads::GoogleAds::V3::Enums::KeywordMatchTypeEnum
+use Google::Ads::GoogleAds::V4::Enums::KeywordPlanNetworkEnum qw(GOOGLE_SEARCH);
+use Google::Ads::GoogleAds::V4::Enums::KeywordMatchTypeEnum
   qw(BROAD PHRASE EXACT);
 use
-  Google::Ads::GoogleAds::V3::Services::KeywordPlanService::KeywordPlanOperation;
+  Google::Ads::GoogleAds::V4::Services::KeywordPlanService::KeywordPlanOperation;
 use
-  Google::Ads::GoogleAds::V3::Services::KeywordPlanCampaignService::KeywordPlanCampaignOperation;
+  Google::Ads::GoogleAds::V4::Services::KeywordPlanCampaignService::KeywordPlanCampaignOperation;
 use
-  Google::Ads::GoogleAds::V3::Services::KeywordPlanAdGroupService::KeywordPlanAdGroupOperation;
+  Google::Ads::GoogleAds::V4::Services::KeywordPlanAdGroupService::KeywordPlanAdGroupOperation;
 use
-  Google::Ads::GoogleAds::V3::Services::KeywordPlanKeywordService::KeywordPlanKeywordOperation;
+  Google::Ads::GoogleAds::V4::Services::KeywordPlanAdGroupKeywordService::KeywordPlanAdGroupKeywordOperation;
 use
-  Google::Ads::GoogleAds::V3::Services::KeywordPlanNegativeKeywordService::KeywordPlanNegativeKeywordOperation;
-
-use Google::Ads::GoogleAds::V3::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V4::Services::KeywordPlanCampaignKeywordService::KeywordPlanCampaignKeywordOperation;
+use Google::Ads::GoogleAds::V4::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -78,10 +77,10 @@ sub add_keyword_plan {
     create_keyword_plan_ad_group($api_client, $customer_id,
     $keyword_plan_campaign_resource);
 
-  create_keyword_plan_keywords($api_client, $customer_id,
+  create_keyword_plan_ad_group_keywords($api_client, $customer_id,
     $keyword_plan_ad_group_resource);
 
-  create_keyword_plan_negative_keywords($api_client, $customer_id,
+  create_keyword_plan_negative_campaign_keywords($api_client, $customer_id,
     $keyword_plan_campaign_resource);
 
   return 1;
@@ -92,16 +91,16 @@ sub create_keyword_plan {
   my ($api_client, $customer_id) = @_;
 
   # Create a keyword plan.
-  my $keyword_plan = Google::Ads::GoogleAds::V3::Resources::KeywordPlan->new({
+  my $keyword_plan = Google::Ads::GoogleAds::V4::Resources::KeywordPlan->new({
       name => "Keyword plan for traffic estimate #" . uniqid(),
       forecastPeriod =>
-        Google::Ads::GoogleAds::V3::Resources::KeywordPlanForecastPeriod->new({
+        Google::Ads::GoogleAds::V4::Resources::KeywordPlanForecastPeriod->new({
           dateInterval => NEXT_QUARTER
         })});
 
   # Create a keyword plan operation.
   my $keyword_plan_operation =
-    Google::Ads::GoogleAds::V3::Services::KeywordPlanService::KeywordPlanOperation
+    Google::Ads::GoogleAds::V4::Services::KeywordPlanService::KeywordPlanOperation
     ->new({
       create => $keyword_plan
     });
@@ -122,7 +121,7 @@ sub create_keyword_plan_campaign {
 
   # Create a keyword plan campaign.
   my $keyword_plan_campaign =
-    Google::Ads::GoogleAds::V3::Resources::KeywordPlanCampaign->new({
+    Google::Ads::GoogleAds::V4::Resources::KeywordPlanCampaign->new({
       name               => "Keyword plan campaign #" . uniqid(),
       cpcBidMicros       => 1000000,
       keywordPlanNetwork => GOOGLE_SEARCH,
@@ -132,21 +131,21 @@ sub create_keyword_plan_campaign {
   # See https://developers.google.com/adwords/api/docs/appendix/geotargeting
   # for the list of geo target IDs.
   $keyword_plan_campaign->{geoTargets} = [
-    Google::Ads::GoogleAds::V3::Resources::KeywordPlanGeoTarget->new({
+    Google::Ads::GoogleAds::V4::Resources::KeywordPlanGeoTarget->new({
         # Geo target constant 2840 is for USA.
         geoTargetConstant =>
-          Google::Ads::GoogleAds::V3::Utils::ResourceNames::geo_target_constant(
+          Google::Ads::GoogleAds::V4::Utils::ResourceNames::geo_target_constant(
           2840)})];
 
   # See https://developers.google.com/adwords/api/docs/appendix/codes-formats#languages
   # for the list of language criteria IDs.
   $keyword_plan_campaign->{languageConstants} = [
     # Language criteria 1000 is for English.
-    Google::Ads::GoogleAds::V3::Utils::ResourceNames::language_constant(1000)];
+    Google::Ads::GoogleAds::V4::Utils::ResourceNames::language_constant(1000)];
 
   # Create a keyword plan campaign operation
   my $keyword_plan_campaign_operation =
-    Google::Ads::GoogleAds::V3::Services::KeywordPlanCampaignService::KeywordPlanCampaignOperation
+    Google::Ads::GoogleAds::V4::Services::KeywordPlanCampaignService::KeywordPlanCampaignOperation
     ->new({
       create => $keyword_plan_campaign
     });
@@ -170,7 +169,7 @@ sub create_keyword_plan_ad_group {
 
   # Create a keyword plan ad group.
   my $keyword_plan_ad_group =
-    Google::Ads::GoogleAds::V3::Resources::KeywordPlanAdGroup->new({
+    Google::Ads::GoogleAds::V4::Resources::KeywordPlanAdGroup->new({
       name                => "Keyword plan ad group #" . uniqid(),
       cpcBidMicros        => 2500000,
       keywordPlanCampaign => $keyword_plan_campaign_resource
@@ -178,7 +177,7 @@ sub create_keyword_plan_ad_group {
 
   # Create a keyword plan ad group operation.
   my $keyword_plan_ad_group_operation =
-    Google::Ads::GoogleAds::V3::Services::KeywordPlanAdGroupService::KeywordPlanAdGroupOperation
+    Google::Ads::GoogleAds::V4::Services::KeywordPlanAdGroupService::KeywordPlanAdGroupOperation
     ->new({
       create => $keyword_plan_ad_group
     });
@@ -196,84 +195,86 @@ sub create_keyword_plan_ad_group {
   return $keyword_plan_ad_group_resource;
 }
 
-# Creates keywords for the keyword plan.
-sub create_keyword_plan_keywords {
+# Creates ad group keywords for the keyword plan.
+sub create_keyword_plan_ad_group_keywords {
   my ($api_client, $customer_id, $keyword_plan_ad_group_resource) = @_;
 
-  # Create the keywords for the keyword plan.
-  my $keyword_plan_keyword1 =
-    Google::Ads::GoogleAds::V3::Resources::KeywordPlanKeyword->new({
+  # Create the ad group keywords for the keyword plan.
+  my $keyword_plan_ad_group_keyword1 =
+    Google::Ads::GoogleAds::V4::Resources::KeywordPlanAdGroupKeyword->new({
       text               => "mars cruise",
       cpcBidMicros       => 2000000,
       matchType          => BROAD,
       keywordPlanAdGroup => $keyword_plan_ad_group_resource
     });
 
-  my $keyword_plan_keyword2 =
-    Google::Ads::GoogleAds::V3::Resources::KeywordPlanKeyword->new({
+  my $keyword_plan_ad_group_keyword2 =
+    Google::Ads::GoogleAds::V4::Resources::KeywordPlanAdGroupKeyword->new({
       text               => "cheap cruise",
       cpcBidMicros       => 1500000,
       matchType          => PHRASE,
       keywordPlanAdGroup => $keyword_plan_ad_group_resource
     });
 
-  my $keyword_plan_keyword3 =
-    Google::Ads::GoogleAds::V3::Resources::KeywordPlanKeyword->new({
+  my $keyword_plan_ad_group_keyword3 =
+    Google::Ads::GoogleAds::V4::Resources::KeywordPlanAdGroupKeyword->new({
       text               => "jupiter cruise",
       cpcBidMicros       => 1990000,
       matchType          => EXACT,
       keywordPlanAdGroup => $keyword_plan_ad_group_resource
     });
 
-  # Create an array of keyword plan keyword operations.
-  my $keyword_plan_keyword_operations = [
+  # Create an array of keyword plan ad group keyword operations.
+  my $operations = [
     map(
-      Google::Ads::GoogleAds::V3::Services::KeywordPlanKeywordService::KeywordPlanKeywordOperation
+      Google::Ads::GoogleAds::V4::Services::KeywordPlanAdGroupKeywordService::KeywordPlanAdGroupKeywordOperation
         ->new(
         {create => $_}
         ),
-      ($keyword_plan_keyword1, $keyword_plan_keyword2, $keyword_plan_keyword3))
-  ];
+      (
+        $keyword_plan_ad_group_keyword1, $keyword_plan_ad_group_keyword2,
+        $keyword_plan_ad_group_keyword3
+      ))];
 
-  # Add the keyword plan keywords.
-  my $keyword_plan_keyword_response =
-    $api_client->KeywordPlanKeywordService()->mutate({
-      customerId => $customer_id,
-      operations => $keyword_plan_keyword_operations
-    });
+  # Add the keyword plan ad group keywords.
+  my $response = $api_client->KeywordPlanAdGroupKeywordService()->mutate({
+    customerId => $customer_id,
+    operations => $operations
+  });
 
-  foreach my $result (@{$keyword_plan_keyword_response->{results}}) {
-    printf "Created keyword for keyword plan: '%s'.\n", $result->{resourceName};
+  foreach my $result (@{$response->{results}}) {
+    printf "Created ad group keyword for keyword plan: '%s'.\n",
+      $result->{resourceName};
   }
 }
 
-# Creates negative keywords for the keyword plan.
-sub create_keyword_plan_negative_keywords {
+# Creates negative campaign keywords for the keyword plan.
+sub create_keyword_plan_negative_campaign_keywords {
   my ($api_client, $customer_id, $keyword_plan_campaign_resource) = @_;
 
-  # Create a negative keyword for the keyword plan.
-  my $keyword_plan_negative_keyword =
-    Google::Ads::GoogleAds::V3::Resources::KeywordPlanNegativeKeyword->new({
+  # Create a negative campaign keyword for the keyword plan.
+  my $keyword_plan_campaign_keyword =
+    Google::Ads::GoogleAds::V4::Resources::KeywordPlanCampaignKeyword->new({
       text                => "moon walk",
       matchType           => BROAD,
+      negative            => "true",
       keywordPlanCampaign => $keyword_plan_campaign_resource
     });
 
-  # Create a keyword plan negative keyword operation.
-  my $keyword_plan_negative_keyword_operation =
-    Google::Ads::GoogleAds::V3::Services::KeywordPlanNegativeKeywordService::KeywordPlanNegativeKeywordOperation
+  # Create a keyword plan campaign keyword operation.
+  my $operation =
+    Google::Ads::GoogleAds::V4::Services::KeywordPlanCampaignKeywordService::KeywordPlanCampaignKeywordOperation
     ->new({
-      create => $keyword_plan_negative_keyword
+      create => $keyword_plan_campaign_keyword
     });
 
-  # Add the keyword plan negative keyword.
-  my $keyword_plan_negative_keyword_response =
-    $api_client->KeywordPlanNegativeKeywordService()->mutate({
+  # Add the keyword plan negative campaign keyword.
+  my $response = $api_client->KeywordPlanCampaignKeywordService()->mutate({
       customerId => $customer_id,
-      operations => [$keyword_plan_negative_keyword_operation]});
+      operations => [$operation]});
 
-  printf "Created negative keyword for keyword plan: '%s'.\n",
-    $keyword_plan_negative_keyword_response->{results}[0]{resourceName};
+  printf "Created negative campaign keyword for keyword plan: '%s'.\n",
+    $response->{results}[0]{resourceName};
 }
 
 # Don't run the example if the file is being included.
@@ -282,7 +283,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
