@@ -25,7 +25,7 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Utils::ResourceNames;
+use Google::Ads::GoogleAds::V4::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -48,7 +48,7 @@ sub generate_forecast_metrics {
   my $forecast_metrics_response =
     $api_client->KeywordPlanService()->generate_forecast_metrics({
       keywordPlan =>
-        Google::Ads::GoogleAds::V3::Utils::ResourceNames::keyword_plan(
+        Google::Ads::GoogleAds::V4::Utils::ResourceNames::keyword_plan(
         $customer_id, $keyword_plan_id
         )});
 
@@ -76,7 +76,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
