@@ -25,13 +25,13 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Enums::KeywordPlanNetworkEnum
+use Google::Ads::GoogleAds::V4::Enums::KeywordPlanNetworkEnum
   qw(GOOGLE_SEARCH GOOGLE_SEARCH_AND_PARTNERS);
-use Google::Ads::GoogleAds::V3::Services::KeywordPlanIdeaService::UrlSeed;
-use Google::Ads::GoogleAds::V3::Services::KeywordPlanIdeaService::KeywordSeed;
+use Google::Ads::GoogleAds::V4::Services::KeywordPlanIdeaService::UrlSeed;
+use Google::Ads::GoogleAds::V4::Services::KeywordPlanIdeaService::KeywordSeed;
 use
-  Google::Ads::GoogleAds::V3::Services::KeywordPlanIdeaService::KeywordAndUrlSeed;
-use Google::Ads::GoogleAds::V3::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V4::Services::KeywordPlanIdeaService::KeywordAndUrlSeed;
+use Google::Ads::GoogleAds::V4::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -52,6 +52,7 @@ my $customer_id = "INSERT_CUSTOMER_ID_HERE";
 # https://developers.google.com/adwords/api/docs/appendix/geotargeting.
 my $location_id_1 = "INSERT_LOCATION_ID_1_HERE";
 my $location_id_2 = "INSERT_LOCATION_ID_2_HERE";
+my $location_ids  = [];
 
 # A language criterion ID. For example, specify 1000 for English. For more
 # information on determining this value, see
@@ -60,6 +61,7 @@ my $language_id = "INSERT_LANGUAGE_ID_HERE";
 
 my $keyword_text_1 = "INSERT_KEYWORD_TEXT_1_HERE";
 my $keyword_text_2 = "INSERT_KEYWORD_TEXT_2_HERE";
+my $keyword_texts  = [];
 
 # Optional: Specify a URL string related to your business to generate ideas.
 my $page_url = undef;
@@ -83,21 +85,21 @@ sub generate_keyword_ideas {
   if (!scalar @$keyword_texts) {
     # Only page URL was specified, so use a UrlSeed.
     $request_option_args->{urlSeed} =
-      Google::Ads::GoogleAds::V3::Services::KeywordPlanIdeaService::UrlSeed->
+      Google::Ads::GoogleAds::V4::Services::KeywordPlanIdeaService::UrlSeed->
       new({
         url => $page_url
       });
   } elsif (not $page_url) {
     # Only keywords were specified, so use a KeywordSeed.
     $request_option_args->{keywordSeed} =
-      Google::Ads::GoogleAds::V3::Services::KeywordPlanIdeaService::KeywordSeed
+      Google::Ads::GoogleAds::V4::Services::KeywordPlanIdeaService::KeywordSeed
       ->new({
         keywords => $keyword_texts
       });
   } else {
     # Both page URL and keywords were specified, so use a KeywordAndUrlSeed.
     $request_option_args->{keywordAndUrlSeed} =
-      Google::Ads::GoogleAds::V3::Services::KeywordPlanIdeaService::KeywordAndUrlSeed
+      Google::Ads::GoogleAds::V4::Services::KeywordPlanIdeaService::KeywordAndUrlSeed
       ->new({
         url      => $page_url,
         keywords => $keyword_texts
@@ -107,8 +109,8 @@ sub generate_keyword_ideas {
   # Create a list of geo target constants based on the resource name of specified
   # location IDs.
   my $geo_target_constants = [
-    map(
-      Google::Ads::GoogleAds::V3::Utils::ResourceNames::geo_target_constant($_),
+    map (
+      Google::Ads::GoogleAds::V4::Utils::ResourceNames::geo_target_constant($_),
       @$location_ids)];
 
   # Generate keyword ideas based on the specified parameters.
@@ -117,7 +119,7 @@ sub generate_keyword_ideas {
       customerId => $customer_id,
       # Set the language resource using the provided language ID.
       language =>
-        Google::Ads::GoogleAds::V3::Utils::ResourceNames::language_constant(
+        Google::Ads::GoogleAds::V4::Utils::ResourceNames::language_constant(
         $language_id),
       # Add the resource name of each location ID to the request.
       geoTargetConstants => $geo_target_constants,
@@ -148,37 +150,31 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
 
 # Parameters passed on the command line will override any parameters set in code.
 GetOptions(
-  "customer_id=s"    => \$customer_id,
-  "location_id_1=i"  => \$location_id_1,
-  "location_id_2=i"  => \$location_id_2,
-  "language_id=i"    => \$language_id,
-  "keyword_text_1=s" => \$keyword_text_1,
-  "keyword_text_2=s" => \$keyword_text_2,
-  "page_url=s"       => \$page_url,
+  "customer_id=s"   => \$customer_id,
+  "location_ids=i"  => \@$location_ids,
+  "language_id=i"   => \$language_id,
+  "keyword_texts=s" => \@$keyword_texts,
+  "page_url=s"      => \$page_url,
 );
+$location_ids  = [$location_id_1,  $location_id_2]  unless @$location_ids;
+$keyword_texts = [$keyword_text_1, $keyword_text_2] unless @$keyword_texts;
 
 # Print the help message if the parameters are not initialized in the code nor
 # in the command line.
 pod2usage(2)
-  if not check_params(
-  $customer_id, $location_id_1,  $location_id_2,
-  $language_id, $keyword_text_1, $keyword_text_2
-  );
+  if
+  not check_params($customer_id, $location_ids, $language_id, $keyword_texts);
 
 # Call the example.
-generate_keyword_ideas(
-  $api_client,
-  $customer_id =~ s/-//gr,
-  [$location_id_1, $location_id_2],
-  $language_id, [$keyword_text_1, $keyword_text_2], $page_url
-);
+generate_keyword_ideas($api_client, $customer_id =~ s/-//gr,
+  $location_ids, $language_id, $keyword_texts, $page_url);
 
 =pod
 
@@ -196,11 +192,9 @@ generate_keyword_ideas.pl [options]
 
     -help                       Show the help message.
     -customer_id                The Google Ads customer ID.
-    -location_id_1              The location criterion ID 1, e.g. specify 21167 for New York.
-    -location_id_2              The location criterion ID 2, e.g. specify 21167 for New York.
+    -location_ids               The location criterion IDs, e.g. specify 21167 for New York.
     -language_id                The language criterion ID, e.g. specify 1000 for English.
-    -keyword_text_1             The keyword text 1, as a seed for ideas.
-    -keyword_text_2             The keyword text 2, as a seed for ideas.
+    -keyword_texts              The keyword texts, as a seed for ideas.
     -page_url                   [optional] URL of a page related to your business.
 
 =cut
