@@ -26,7 +26,7 @@ use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::Utils::SearchGoogleAdsIterator;
 use
-  Google::Ads::GoogleAds::V3::Services::GoogleAdsService::SearchGoogleAdsRequest;
+  Google::Ads::GoogleAds::V4::Services::GoogleAdsService::SearchGoogleAdsRequest;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -47,7 +47,7 @@ my $customer_id = "INSERT_CUSTOMER_ID_HERE";
 sub get_text_ad_recommendations {
   my ($api_client, $customer_id) = @_;
 
-  # Creates the searcyh query.
+  # Creates the search query.
   my $search_query =
     "SELECT recommendation.type, recommendation.campaign, " .
     "recommendation.text_ad_recommendation " .
@@ -56,7 +56,7 @@ sub get_text_ad_recommendations {
   # Create a search Google Ads request that will retrieve all recommendations for
   # text ads using pages of the specified page size.
   my $search_request =
-    Google::Ads::GoogleAds::V3::Services::GoogleAdsService::SearchGoogleAdsRequest
+    Google::Ads::GoogleAds::V4::Services::GoogleAdsService::SearchGoogleAdsRequest
     ->new({
       customerId => $customer_id,
       query      => $search_query,
@@ -114,7 +114,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
