@@ -25,9 +25,9 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Resources::RemarketingAction;
+use Google::Ads::GoogleAds::V4::Resources::RemarketingAction;
 use
-  Google::Ads::GoogleAds::V3::Services::RemarketingActionService::RemarketingActionOperation;
+  Google::Ads::GoogleAds::V4::Services::RemarketingActionService::RemarketingActionOperation;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -51,12 +51,12 @@ sub add_remarketing_action {
 
   # Create a remarketing action with the specified name.
   my $remarketing_action =
-    Google::Ads::GoogleAds::V3::Resources::RemarketingAction->new({
+    Google::Ads::GoogleAds::V4::Resources::RemarketingAction->new({
       name => "Remarketing action #" . uniqid()});
 
   # Create a remarketing action operation.
   my $remarketing_action_operation =
-    Google::Ads::GoogleAds::V3::Services::RemarketingActionService::RemarketingActionOperation
+    Google::Ads::GoogleAds::V4::Services::RemarketingActionService::RemarketingActionOperation
     ->new({
       create => $remarketing_action
     });
@@ -122,7 +122,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
