@@ -25,15 +25,15 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Enums::ConversionAdjustmentTypeEnum
+use Google::Ads::GoogleAds::V4::Enums::ConversionAdjustmentTypeEnum
   qw(RESTATEMENT);
 use
-  Google::Ads::GoogleAds::V3::Services::ConversionAdjustmentUploadService::ConversionAdjustment;
+  Google::Ads::GoogleAds::V4::Services::ConversionAdjustmentUploadService::ConversionAdjustment;
 use
-  Google::Ads::GoogleAds::V3::Services::ConversionAdjustmentUploadService::GclidDateTimePair;
+  Google::Ads::GoogleAds::V4::Services::ConversionAdjustmentUploadService::GclidDateTimePair;
 use
-  Google::Ads::GoogleAds::V3::Services::ConversionAdjustmentUploadService::RestatementValue;
-use Google::Ads::GoogleAds::V3::Utils::ResourceNames;
+  Google::Ads::GoogleAds::V4::Services::ConversionAdjustmentUploadService::RestatementValue;
+use Google::Ads::GoogleAds::V4::Utils::ResourceNames;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -67,15 +67,15 @@ sub upload_conversion_adjustment {
   # Associate conversion adjustments with the existing conversion action.
   # The GCLID should have been uploaded before with a conversion.
   my $conversion_adjustment =
-    Google::Ads::GoogleAds::V3::Services::ConversionAdjustmentUploadService::ConversionAdjustment
+    Google::Ads::GoogleAds::V4::Services::ConversionAdjustmentUploadService::ConversionAdjustment
     ->new({
       conversionAction =>
-        Google::Ads::GoogleAds::V3::Utils::ResourceNames::conversion_action(
+        Google::Ads::GoogleAds::V4::Utils::ResourceNames::conversion_action(
         $customer_id, $conversion_action_id
         ),
       adjustmentType => $adjustment_type,
       gclidDateTimePair =>
-        Google::Ads::GoogleAds::V3::Services::ConversionAdjustmentUploadService::GclidDateTimePair
+        Google::Ads::GoogleAds::V4::Services::ConversionAdjustmentUploadService::GclidDateTimePair
         ->new({
           gclid              => $gclid,
           conversionDateTime => $conversion_date_time
@@ -86,7 +86,7 @@ sub upload_conversion_adjustment {
 
   # Set adjusted value for adjustment type RESTATEMENT.
   $conversion_adjustment->{restatementValue} =
-    Google::Ads::GoogleAds::V3::Services::ConversionAdjustmentUploadService::RestatementValue
+    Google::Ads::GoogleAds::V4::Services::ConversionAdjustmentUploadService::RestatementValue
     ->new({
       adjustedValue => $restatement_value
     }) if defined $restatement_value && $adjustment_type eq RESTATEMENT;
@@ -125,7 +125,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
