@@ -35,33 +35,33 @@ use FindBin qw($Bin);
 use lib "$Bin/../../lib";
 use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
-use Google::Ads::GoogleAds::V3::Resources::CampaignBudget;
-use Google::Ads::GoogleAds::V3::Resources::Campaign;
-use Google::Ads::GoogleAds::V3::Resources::ShoppingSetting;
-use Google::Ads::GoogleAds::V3::Resources::AdGroup;
-use Google::Ads::GoogleAds::V3::Resources::AdGroupAd;
-use Google::Ads::GoogleAds::V3::Resources::Ad;
-use Google::Ads::GoogleAds::V3::Resources::AdGroupCriterion;
-use Google::Ads::GoogleAds::V3::Common::MaximizeConversionValue;
-use Google::Ads::GoogleAds::V3::Common::ShoppingSmartAdInfo;
-use Google::Ads::GoogleAds::V3::Common::ListingGroupInfo;
-use Google::Ads::GoogleAds::V3::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
-use Google::Ads::GoogleAds::V3::Enums::AdvertisingChannelTypeEnum qw(SHOPPING);
-use Google::Ads::GoogleAds::V3::Enums::AdvertisingChannelSubTypeEnum
+use Google::Ads::GoogleAds::V4::Resources::CampaignBudget;
+use Google::Ads::GoogleAds::V4::Resources::Campaign;
+use Google::Ads::GoogleAds::V4::Resources::ShoppingSetting;
+use Google::Ads::GoogleAds::V4::Resources::AdGroup;
+use Google::Ads::GoogleAds::V4::Resources::AdGroupAd;
+use Google::Ads::GoogleAds::V4::Resources::Ad;
+use Google::Ads::GoogleAds::V4::Resources::AdGroupCriterion;
+use Google::Ads::GoogleAds::V4::Common::MaximizeConversionValue;
+use Google::Ads::GoogleAds::V4::Common::ShoppingSmartAdInfo;
+use Google::Ads::GoogleAds::V4::Common::ListingGroupInfo;
+use Google::Ads::GoogleAds::V4::Enums::BudgetDeliveryMethodEnum qw(STANDARD);
+use Google::Ads::GoogleAds::V4::Enums::AdvertisingChannelTypeEnum qw(SHOPPING);
+use Google::Ads::GoogleAds::V4::Enums::AdvertisingChannelSubTypeEnum
   qw(SHOPPING_SMART_ADS);
-use Google::Ads::GoogleAds::V3::Enums::AdGroupTypeEnum;
-use Google::Ads::GoogleAds::V3::Enums::CampaignStatusEnum;
-use Google::Ads::GoogleAds::V3::Enums::AdGroupStatusEnum;
-use Google::Ads::GoogleAds::V3::Enums::AdGroupAdStatusEnum;
-use Google::Ads::GoogleAds::V3::Enums::ListingGroupTypeEnum qw(UNIT);
-use Google::Ads::GoogleAds::V3::Enums::AdGroupCriterionStatusEnum;
+use Google::Ads::GoogleAds::V4::Enums::AdGroupTypeEnum;
+use Google::Ads::GoogleAds::V4::Enums::CampaignStatusEnum;
+use Google::Ads::GoogleAds::V4::Enums::AdGroupStatusEnum;
+use Google::Ads::GoogleAds::V4::Enums::AdGroupAdStatusEnum;
+use Google::Ads::GoogleAds::V4::Enums::ListingGroupTypeEnum qw(UNIT);
+use Google::Ads::GoogleAds::V4::Enums::AdGroupCriterionStatusEnum;
 use
-  Google::Ads::GoogleAds::V3::Services::CampaignBudgetService::CampaignBudgetOperation;
-use Google::Ads::GoogleAds::V3::Services::CampaignService::CampaignOperation;
-use Google::Ads::GoogleAds::V3::Services::AdGroupService::AdGroupOperation;
-use Google::Ads::GoogleAds::V3::Services::AdGroupAdService::AdGroupAdOperation;
+  Google::Ads::GoogleAds::V4::Services::CampaignBudgetService::CampaignBudgetOperation;
+use Google::Ads::GoogleAds::V4::Services::CampaignService::CampaignOperation;
+use Google::Ads::GoogleAds::V4::Services::AdGroupService::AdGroupOperation;
+use Google::Ads::GoogleAds::V4::Services::AdGroupAdService::AdGroupAdOperation;
 use
-  Google::Ads::GoogleAds::V3::Services::AdGroupCriterionService::AdGroupCriterionOperation;
+  Google::Ads::GoogleAds::V4::Services::AdGroupCriterionService::AdGroupCriterionOperation;
 
 use Getopt::Long qw(:config auto_help);
 use Pod::Usage;
@@ -121,7 +121,7 @@ sub add_campaign_budget {
 
   # Create a campaign budget.
   my $campaign_budget =
-    Google::Ads::GoogleAds::V3::Resources::CampaignBudget->new({
+    Google::Ads::GoogleAds::V4::Resources::CampaignBudget->new({
       name           => "Interplanetary Cruise Budget #" . uniqid(),
       deliveryMethod => STANDARD,
       # The budget is specified in the local currency of the account.
@@ -134,7 +134,7 @@ sub add_campaign_budget {
 
   # Create a campaign budget operation.
   my $campaign_budget_operation =
-    Google::Ads::GoogleAds::V3::Services::CampaignBudgetService::CampaignBudgetOperation
+    Google::Ads::GoogleAds::V4::Services::CampaignBudgetService::CampaignBudgetOperation
     ->new({create => $campaign_budget});
 
   # Add the budget.
@@ -157,14 +157,14 @@ sub add_smart_shopping_campaign {
     = @_;
 
   # Create a smart shopping campaign.
-  my $campaign = Google::Ads::GoogleAds::V3::Resources::Campaign->new({
+  my $campaign = Google::Ads::GoogleAds::V4::Resources::Campaign->new({
       name => "Interplanetary Cruise Campaign #" . uniqid(),
       # Configure settings related to shopping campaigns including advertising
       # channel type, advertising channel sub-type and shopping setting.
       advertisingChannelType    => SHOPPING,
       advertisingChannelSubType => SHOPPING_SMART_ADS,
       shoppingSetting =>
-        Google::Ads::GoogleAds::V3::Resources::ShoppingSetting->new({
+        Google::Ads::GoogleAds::V4::Resources::ShoppingSetting->new({
           merchantId => $merchant_center_account_id,
           # Set the sales country of products to include in the campaign.
           # Only products from Merchant Center targeting this country will
@@ -175,7 +175,7 @@ sub add_smart_shopping_campaign {
       # Recommendation: Set the campaign to PAUSED when creating it to prevent
       # the ads from immediately serving. Set to ENABLED once you've added
       # targeting and the ads are ready to serve.
-      status => Google::Ads::GoogleAds::V3::Enums::CampaignStatusEnum::PAUSED,
+      status => Google::Ads::GoogleAds::V4::Enums::CampaignStatusEnum::PAUSED,
       # Bidding strategy must be set directly on the campaign.
       # Setting a portfolio bidding strategy by resource name is not supported.
       # Maximize conversion value is the only strategy supported for smart shopping
@@ -185,7 +185,7 @@ sub add_smart_shopping_campaign {
       # For more information on maximize conversion value, see the support article:
       # http://support.google.com/google-ads/answer/7684216.
       maximizeConversionValue =>
-        Google::Ads::GoogleAds::V3::Common::MaximizeConversionValue->new(
+        Google::Ads::GoogleAds::V4::Common::MaximizeConversionValue->new(
         {targetRoas => 3.5}
         ),
       # Set the budget.
@@ -194,7 +194,7 @@ sub add_smart_shopping_campaign {
 
   # Create a campaign operation.
   my $campaign_operation =
-    Google::Ads::GoogleAds::V3::Services::CampaignService::CampaignOperation->
+    Google::Ads::GoogleAds::V4::Services::CampaignService::CampaignOperation->
     new({create => $campaign});
 
   # Add the campaign.
@@ -213,19 +213,19 @@ sub add_smart_shopping_ad_group {
   my ($api_client, $customer_id, $campaign_resource_name) = @_;
 
   # Create an ad group.
-  my $ad_group = Google::Ads::GoogleAds::V3::Resources::AdGroup->new({
+  my $ad_group = Google::Ads::GoogleAds::V4::Resources::AdGroup->new({
     name     => "Earth to Mars Cruises #" . uniqid(),
     campaign => $campaign_resource_name,
     # Set the ad group type to SHOPPING_SMART_ADS. This cannot be set to
     # other types
     type =>
-      Google::Ads::GoogleAds::V3::Enums::AdGroupTypeEnum::SHOPPING_SMART_ADS,
-    status => Google::Ads::GoogleAds::V3::Enums::AdGroupStatusEnum::ENABLED
+      Google::Ads::GoogleAds::V4::Enums::AdGroupTypeEnum::SHOPPING_SMART_ADS,
+    status => Google::Ads::GoogleAds::V4::Enums::AdGroupStatusEnum::ENABLED
   });
 
   # Create an ad group operation.
   my $ad_group_operation =
-    Google::Ads::GoogleAds::V3::Services::AdGroupService::AdGroupOperation->
+    Google::Ads::GoogleAds::V4::Services::AdGroupService::AdGroupOperation->
     new({create => $ad_group});
 
   # Add the ad group.
@@ -244,20 +244,20 @@ sub add_smart_shopping_ad_group_ad {
   my ($api_client, $customer_id, $ad_group_resource_name) = @_;
 
   # Create an ad group ad and set a shopping smart ad to it.
-  my $ad_group_ad = Google::Ads::GoogleAds::V3::Resources::AdGroupAd->new({
+  my $ad_group_ad = Google::Ads::GoogleAds::V4::Resources::AdGroupAd->new({
       # Set the ad group.
       adGroup => $ad_group_resource_name,
       # Set a new smart shopping ad.
-      ad => Google::Ads::GoogleAds::V3::Resources::Ad->new({
+      ad => Google::Ads::GoogleAds::V4::Resources::Ad->new({
           shoppingSmartAd =>
-            Google::Ads::GoogleAds::V3::Common::ShoppingSmartAdInfo->new()}
+            Google::Ads::GoogleAds::V4::Common::ShoppingSmartAdInfo->new()}
       ),
-      status => Google::Ads::GoogleAds::V3::Enums::AdGroupAdStatusEnum::PAUSED
+      status => Google::Ads::GoogleAds::V4::Enums::AdGroupAdStatusEnum::PAUSED
     });
 
   # Create an ad group ad operation.
   my $ad_group_ad_operation =
-    Google::Ads::GoogleAds::V3::Services::AdGroupAdService::AdGroupAdOperation
+    Google::Ads::GoogleAds::V4::Services::AdGroupAdService::AdGroupAdOperation
     ->new({create => $ad_group_ad});
 
   # Add the ad group ad.
@@ -283,23 +283,23 @@ sub add_shopping_listing_group {
   # This will be the listing group for 'All products' and will contain a
   # single root node.
   my $ad_group_criterion =
-    Google::Ads::GoogleAds::V3::Resources::AdGroupCriterion->new({
+    Google::Ads::GoogleAds::V4::Resources::AdGroupCriterion->new({
       # Set the ad group.
       adGroup => $ad_group_resource_name,
       # Create a new listing group. This will be the top-level "root" node.
       # Set the type of the listing group to be a biddable unit.
-      listingGroup => Google::Ads::GoogleAds::V3::Common::ListingGroupInfo->new(
+      listingGroup => Google::Ads::GoogleAds::V4::Common::ListingGroupInfo->new(
         {
           type => UNIT
         }
       ),
       status =>
-        Google::Ads::GoogleAds::V3::Enums::AdGroupCriterionStatusEnum::ENABLED
+        Google::Ads::GoogleAds::V4::Enums::AdGroupCriterionStatusEnum::ENABLED
     });
 
   # Create an ad group criterion operation.
   my $ad_group_criterion_operation =
-    Google::Ads::GoogleAds::V3::Services::AdGroupCriterionService::AdGroupCriterionOperation
+    Google::Ads::GoogleAds::V4::Services::AdGroupCriterionService::AdGroupCriterionOperation
     ->new({create => $ad_group_criterion});
 
   # Add the listing group criterion.
@@ -321,7 +321,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client = Google::Ads::GoogleAds::Client->new({version => "V3"});
+my $api_client = Google::Ads::GoogleAds::Client->new();
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
