@@ -37,7 +37,9 @@ sub remove_unassigned_fields {
 sub check_params {
   my (@params) = @_;
   foreach my $param (@params) {
-    if (!defined $param || $param =~ /INSERT_.*_HERE/) {
+    if (ref $param eq "ARRAY") {
+      return 0 if !(@$param && check_params(@$param));
+    } elsif (!defined $param || $param =~ /INSERT_.*_HERE/) {
       return 0;
     }
   }
@@ -184,7 +186,7 @@ arguments.
 
 I<path_template>: the path template to expand. The format could be:
 'customers/{customer_id}/adGroups/{ad_group_id}' or
-'v3/customers/{+customerId}/adGroups:mutate'.
+'v4/customers/{+customerId}/adGroups:mutate'.
 
 =item *
 
